@@ -1,5 +1,5 @@
 #!/bin/sh
-# configversion: 0f596a22eb8ff28f226bf37338e9b741
+# configversion: e8103b71db9fd8eb94508d9782ad749a
 # SPDX-License-Identifier: AGPL-3.0-only
 # Copyright 2022 Sxmo Contributors
 # shellcheck disable=SC2154
@@ -81,6 +81,7 @@ write_line_app nheko "$icon_msg Nheko" "nheko"
 write_line_app nvim "$icon_vim Neovim" "sxmo_terminal.sh nvim"
 write_line_app netsurf "$icon_glb Netsurf" "netsurf"
 write_line_app newsboat "$icon_rss Newsboat" "sxmo_terminal.sh newsboat"
+write_line_app com.gitlab.newsflash "$icon_rss Newsflash" com.gitlab.newsflash
 write_line_app nnn "$icon_dir Nnn" "sxmo_terminal.sh nnn"
 write_line_app pidgin "$icon_msg Pidgin" "pidgin"
 write_line_app pulsemixer "$icon_mus Pulsemixer" "sxmo_terminal.sh pulsemixer"
@@ -91,6 +92,7 @@ write_line_app profanity "$icon_msg Profanity" "sxmo_terminal.sh profanity"
 write_line_app qutebrowser "$icon_glb Qutebrowser" "qutebrowser"
 write_line_app ranger "$icon_dir Ranger" "sxmo_terminal.sh ranger"
 write_line_app sacc "$icon_glb Sacc" "sxmo_terminal.sh sacc i-logout.cz/1/bongusta"
+write_line_app secrets "$icon_lck Secrets" "secrets"
 write_line_app senpai "$icon_msg Senpai" "sxmo_terminal.sh senpai"
 write_line_app sic "$icon_msg Sic" "sxmo_terminal.sh sic"
 ([ "$SXMO_WM" = dwm ] && command -v st >/dev/null) && \
@@ -105,6 +107,7 @@ write_line_app com.github.bleakgrey.tootle "$icon_msg Tootle" "com.github.bleakg
 write_line_app totem "$icon_mvi Totem" "totem"
 write_line_app tuir "$icon_red Tuir" "sxmo_terminal.sh tuir"
 write_line_app tut "$icon_msg Tut" "sxmo_terminal.sh tut"
+write_line_app waydroid "$icon_and Waydroid" "waydroid show-full-ui"
 write_line_app weechat "$icon_msg Weechat" "sxmo_terminal.sh weechat"
 write_line_app pavucontrol "$icon_mus Pavucontrol" "pavucontrol"
 write_line_app w3m "$icon_glb W3m" "sxmo_terminal.sh w3m duck.com"
@@ -113,6 +116,7 @@ write_line_app vimb "$icon_glb Vimb" "vimb"
 write_line_app vis "$icon_vim Vis" "sxmo_terminal.sh vis"
 write_line_app vlc "$icon_mvi Vlc" "vlc"
 write_line_app vte-2.91 "$icon_trm VTE 3" "vte-2.91"
+write_line_app vte-2.91-gtk4 "$icon_trm VTE 3 (GTK-4)" "vte-2.91-gtk4"
 ([ "$SXMO_WM" = dwm ] && command -v xcalc >/dev/null) && \
 	write_line "$icon_clc Xcalc" "xcalc"
 write_line_app xournal "$icon_bok Xournal" "xournal"
