@@ -1,5 +1,5 @@
 #!/bin/sh
-# configversion: 1db6ffa4ff0f58de1ea8e3c0440ec081
+# configversion: a5cd73350a63875311280e53a64cc888
 # SPDX-License-Identifier: AGPL-3.0-only
 # Copyright 2022 Sxmo Contributors
 
@@ -30,6 +30,7 @@ case "$SXMO_WM" in
 		superctl start sxmo_wob
 		superctl start sxmo_menumode_toggler
 		superctl start bonsaid
+		swaymsg output '*' bg "$SXMO_BG_IMG" fill
 		;;
 	dwm)
 		superctl start dunst
@@ -45,18 +46,34 @@ case "$SXMO_WM" in
 		superctl start autocutsel
 		superctl start autocutsel-primary
 		superctl start sxmo-x11-status
+		superctl start bonsaid
 		[ -n "$SXMO_MONITOR" ] && xrandr --output "$SXMO_MONITOR" --primary
+		feh --bg-fill "$SXMO_BG_IMG"
 		;;
 esac
 
 # To setup initial lock state
 sxmo_hook_unlock.sh
 
-# Turn on the dbus-monitors for modem-related tasks
-superctl start sxmo_modemmonitor
+# Turn on auto-suspend
+if [ -w "/sys/power/wakeup_count" ] && [ -f "/sys/power/wake_lock" ]; then
+	superctl start sxmo_autosuspend
+fi
+
+# Turn on lisgd
+superctl start sxmo_hook_lisgd
+
+if [ "$(command -v ModemManager)" ]; then
+	# Turn on the dbus-monitors for modem-related tasks
+	superctl start sxmo_modemmonitor
+
+	# place a wakelock for 120s to allow the modem to fully warm up (eg25 +
+	# elogind/systemd would do this for us, but we don't use those.)
+	sxmo_wakelock.sh lock modem_warming_up 120s
+fi
 
 # Start the desktop widget (e.g. clock)
-superctl start sxmo_desktop_widget
+superctl start sxmo_conky
 
 # Monitor the battery
 superctl start sxmo_battery_monitor
@@ -73,8 +90,6 @@ superctl start sxmo_soundmonitor
 # Play a funky startup tune if you want (disabled by default)
 #mpv --quiet --no-video ~/welcome.ogg &
 
-# Set a background image: edit ~/.config/sxmo/sway or ~/.config/sxmo/xinit
-
 # add some warnings if things are not setup correctly
 deviceprofile="$(command -v "sxmo_deviceprofile_$SXMO_DEVICE_NAME.sh")"
 
