@@ -1,5 +1,5 @@
 #!/bin/sh
-# configversion: 1717e9421576d738f711e3da97de1a9f
+# configversion: 598208ca50b8363db243846eeabef065
 # SPDX-License-Identifier: AGPL-3.0-only
 # Copyright 2022 Sxmo Contributors
 
@@ -9,22 +9,30 @@
 
 # This hook is called when the system becomes unlocked again
 
+exec 3<> "$SXMO_STATE.lock"
+flock -x 3
+
 sxmo_log "transitioning to stage unlock"
 printf unlock > "$SXMO_STATE"
 
-sxmo_uniq_exec.sh sxmo_led.sh blink red green &
-sxmo_daemons.sh start state_change_bar sxmo_hook_statusbar.sh state_change
+sxmo_wakelock.sh lock not_screenoff infinite
+
+sxmo_led.sh blink red green &
+sxmo_hook_statusbar.sh state_change &
 
 sxmo_wm.sh dpms off
 sxmo_wm.sh inputevent touchscreen on
-superctl start sxmo_hook_lisgd
 
-# avoid dangling purple blinking when usb wakeup + power button…
 sxmo_daemons.sh stop periodic_blink
+sxmo_daemons.sh stop periodic_wakelock_check
 
-NETWORKRTCSCAN="/sys/module/$SXMO_WIFI_MODULE/parameters/rtw_scan_interval_thr"
-if [ -w "$NETWORKRTCSCAN" ]; then
-	echo 16000 > "$NETWORKRTCSCAN"
+# see https://todo.sr.ht/~mil/sxmo-tickets/150
+# We set the scan interval threshold here to
+# 16000 (16s) the default, since in sxmo_hook_postwake.sh
+# we set it to 1200 (.12s) so that we can reconnect to wifi
+# quicker after resuming from suspend.
+if [ 1 = "$SXMO_RTW_SCAN_INTERVAL" ]; then
+	echo 16000 > "/sys/module/$SXMO_WIFI_MODULE/parameters/rtw_scan_interval_thr"
 fi
 
 # Go to lock after 120 seconds of inactivity
@@ -46,5 +54,4 @@ else
 	esac
 fi
 
-sxmo_daemons.sh start periodic_state_mutex_check \
-	sxmo_run_aligned.sh 60 sxmo_uniq_exec.sh sxmo_hook_check_state_mutexes.sh
+wait
