@@ -9,9 +9,9 @@
 _sxmo_is_running() {
 	unset SXMO_WM
 
-	if [ -f "${XDG_RUNTIME_DIR:-/dev/shm/user/$(id -u)}"/sxmo.swaysock ]; then
+	if [ -f "${XDG_RUNTIME_DIR}"/sxmo.swaysock ]; then
 		unset SWAYSOCK
-		if SWAYSOCK="$(cat "${XDG_RUNTIME_DIR:-/dev/shm/user/$(id -u)}"/sxmo.swaysock)" \
+		if SWAYSOCK="$(cat "${XDG_RUNTIME_DIR}"/sxmo.swaysock)" \
 			swaymsg 2>/dev/null; then
 			printf "Detected the Sway environment\n" >&2
 			export SXMO_WM=sway
@@ -29,6 +29,22 @@ _sxmo_is_running() {
 	return 1
 }
 
+_sxmo_find_runtime_dir() {
+	# Take what we gave to you
+	if [ -n "$XDG_RUNTIME_DIR" ]; then
+		printf %s "$XDG_RUNTIME_DIR"
+		return
+	fi
+
+	if [ -d "/var/run/user/$(id -u)" ]; then
+		printf "/var/run/user/%s" "$(id -u)"
+		return
+	fi
+
+	# Fallback to a shared memory location
+	printf "/dev/shm/user/%s" "$(id -u)"
+}
+
 _sxmo_load_environments() {
 	# Determine current operating system see os-release(5)
 	# https://www.linux.org/docs/man5/os-release.html
@@ -44,7 +60,8 @@ _sxmo_load_environments() {
 	export XDG_DATA_HOME="${XDG_DATA_HOME:-$HOME/.local/share}"
 	export XDG_CACHE_HOME="${XDG_CACHE_HOME:-$HOME/.cache}"
 	export XDG_CONFIG_HOME="${XDG_CONFIG_HOME:-$HOME/.config}"
-	export XDG_RUNTIME_DIR="${XDG_RUNTIME_DIR:-/dev/shm/user/$(id -u)}"
+	XDG_RUNTIME_DIR="$(_sxmo_find_runtime_dir)"
+	export XDG_RUNTIME_DIR
 	export XDG_DATA_DIRS="${XDG_DATA_DIRS:-/usr/local/share:/usr/share}"
 	export XDG_STATE_HOME="${XDG_STATE_HOME:-$HOME/.local/state}"
 
@@ -58,7 +75,7 @@ _sxmo_load_environments() {
 	export SXMO_NOTIFDIR="${SXMO_NOTIFDIR:-$XDG_DATA_HOME/sxmo/notifications}"
 	export SXMO_UNSUSPENDREASONFILE="${SXMO_UNSUSPENDREASONFILE:-$XDG_RUNTIME_DIR/sxmo.suspend.reason}"
 
-	export BEMENU_OPTS="${BEMENU_OPTS:---fn 'Monospace 14' --scrollbar autohide -s -n -w -c -l8 -M 40 -H 20 --cb "#222222" --cf "#bbbbbb" --tb "#005577" --tf "#eeeeee" --fb "#222222" --ff "#bbbbbb" --nb "#222222" --af "#bbbbbb" --ab "#222222" --nf "#bbbbbb" --hb "#005577" --hf "#eeeeee" --scb "#005577" --scf "#eeeeee" --fbb "#eeeeee" --fbf "#222222"}"
+	export BEMENU_OPTS="${BEMENU_OPTS:---fn 'Sxmo 14' --scrollbar autohide -s -n -w -c -l8 -M 40 -H 20 --cb "#222222" --cf "#bbbbbb" --tb "#005577" --tf "#eeeeee" --fb "#222222" --ff "#bbbbbb" --nb "#222222" --af "#bbbbbb" --ab "#222222" --nf "#bbbbbb" --hb "#005577" --hf "#eeeeee" --scb "#005577" --scf "#eeeeee" --fbb "#eeeeee" --fbf "#222222"}"
 
 	export EDITOR="${EDITOR:-vim}"
 	export BROWSER="${BROWSER:-firefox}"
@@ -75,16 +92,29 @@ _sxmo_load_environments() {
 			. "$deviceprofile"
 			printf "deviceprofile file %s loaded.\n" "$deviceprofile"
 		else
-			printf "WARNING: deviceprofile file not found for %s.\n" "$SXMO_DEVICE_NAME"
+			printf "WARNING: deviceprofile file not found for %s. Most device functions will not work. Please read: https://sxmo.org/deviceprofile \n" "$SXMO_DEVICE_NAME"
+
+			# on a new device, power button won't work
+			# so make sure we don't go into screenoff
+			# or suspend
+			touch "$XDG_CACHE_HOME"/sxmo/sxmo.nosuspend
+			touch "$XDG_CACHE_HOME"/sxmo/sxmo.noidle
+
+			SXMO_DEVICE_NAME=unknown
 		fi
 		unset deviceprofile
 	fi
 
 	if [ -n "$SXMO_DEVICE_NAME" ]; then
+		_device_hooks_path="$(xdg_data_path "sxmo/default_hooks/$SXMO_DEVICE_NAME" 0 ':')"
+		if [ -z "$_device_hooks_path" ]; then
+			_device_hooks_path="$(xdg_data_path "sxmo/default_hooks/three_button_touchscreen" 0 ':')"
+		fi
+
 		PATH="\
 $XDG_CONFIG_HOME/sxmo/hooks/$SXMO_DEVICE_NAME:\
 $XDG_CONFIG_HOME/sxmo/hooks:\
-$(xdg_data_path "sxmo/default_hooks/$SXMO_DEVICE_NAME" 0 ':'):\
+$_device_hooks_path:\
 $(xdg_data_path "sxmo/default_hooks" 0 ':'):\
 $PATH"
 		export PATH
@@ -95,7 +125,10 @@ $PATH"
 }
 
 _sxmo_grab_session() {
+	XDG_RUNTIME_DIR="$(_sxmo_find_runtime_dir)"
+	export XDG_RUNTIME_DIR
 	if ! _sxmo_is_running; then
+		unset XDG_RUNTIME_DIR
 		return
 	fi
 
